@@ -111,6 +111,8 @@ const (
 	UntrackedModes properties.Property = "untracked_modes"
 	// IgnoreSubmodules list the optional ignore-submodules mode per repo
 	IgnoreSubmodules properties.Property = "ignore_submodules"
+	// MappedBranches allows overriding certain branches with an icon/text
+	MappedBranches properties.Property = "mapped_branches"
 
 	DETACHED     = "(detached)"
 	BRANCHPREFIX = "ref: refs/heads/"
@@ -333,7 +335,7 @@ func (g *Git) getBareRepoInfo() {
 	head := g.FileContents(g.workingDir, "HEAD")
 	branchIcon := g.props.GetString(BranchIcon, "\uE0A0")
 	g.Ref = strings.Replace(head, "ref: refs/heads/", "", 1)
-	g.HEAD = fmt.Sprintf("%s%s", branchIcon, g.Ref)
+	g.HEAD = fmt.Sprintf("%s%s", branchIcon, g.formatBranch(g.Ref))
 	if !g.props.GetBool(FetchUpstreamIcon, false) {
 		return
 	}
@@ -550,23 +552,28 @@ func (g *Git) setGitStatus() {
 		g.Working.add(workingCode)
 		g.Staging.add(stagingCode)
 	}
+
 	const (
 		HASH         = "# branch.oid "
 		REF          = "# branch.head "
 		UPSTREAM     = "# branch.upstream "
 		BRANCHSTATUS = "# branch.ab "
 	)
+
 	// firstly assume that upstream is gone
 	g.UpstreamGone = true
 	statusFormats := g.props.GetKeyValueMap(StatusFormats, map[string]string{})
+
 	g.Working = &GitStatus{ScmStatus: ScmStatus{Formats: statusFormats}}
 	g.Staging = &GitStatus{ScmStatus: ScmStatus{Formats: statusFormats}}
+
 	untrackedMode := g.getUntrackedFilesMode()
 	args := []string{"status", untrackedMode, "--branch", "--porcelain=2"}
 	ignoreSubmodulesMode := g.getIgnoreSubmodulesMode()
 	if len(ignoreSubmodulesMode) > 0 {
 		args = append(args, ignoreSubmodulesMode)
 	}
+
 	output := g.getGitCommandOutput(args...)
 	for _, line := range strings.Split(output, "\n") {
 		if strings.HasPrefix(line, HASH) && len(line) >= len(HASH)+7 {
@@ -574,16 +581,19 @@ func (g *Git) setGitStatus() {
 			g.Hash = line[len(HASH):]
 			continue
 		}
+
 		if strings.HasPrefix(line, REF) && len(line) > len(REF) {
 			g.Ref = line[len(REF):]
 			continue
 		}
+
 		if strings.HasPrefix(line, UPSTREAM) && len(line) > len(UPSTREAM) {
 			// status reports upstream, but upstream may be gone (must check BRANCHSTATUS)
 			g.Upstream = line[len(UPSTREAM):]
 			g.UpstreamGone = true
 			continue
 		}
+
 		if strings.HasPrefix(line, BRANCHSTATUS) && len(line) > len(BRANCHSTATUS) {
 			status := line[len(BRANCHSTATUS):]
 			splitted := strings.Split(status, " ")
@@ -596,6 +606,7 @@ func (g *Git) setGitStatus() {
 			g.UpstreamGone = false
 			continue
 		}
+
 		addToStatus(line)
 	}
 }
@@ -615,7 +626,7 @@ func (g *Git) setGitHEADContext() {
 		g.Detached = true
 		g.setPrettyHEADName()
 	} else {
-		head := g.formatHEAD(g.Ref)
+		head := g.formatBranch(g.Ref)
 		g.HEAD = fmt.Sprintf("%s%s", branchIcon, head)
 	}
 
@@ -633,7 +644,7 @@ func (g *Git) setGitHEADContext() {
 			origin = formatDetached()
 		} else {
 			head = strings.Replace(head, "refs/heads/", "", 1)
-			origin = branchIcon + g.formatHEAD(head)
+			origin = branchIcon + g.formatBranch(head)
 		}
 		return origin
 	}
@@ -642,7 +653,7 @@ func (g *Git) setGitHEADContext() {
 		g.Rebase = true
 		origin := getPrettyNameOrigin("rebase-merge/head-name")
 		onto := g.getGitRefFileSymbolicName("rebase-merge/onto")
-		onto = g.formatHEAD(onto)
+		onto = g.formatBranch(onto)
 		step := g.FileContents(g.workingDir, "rebase-merge/msgnum")
 		total := g.FileContents(g.workingDir, "rebase-merge/end")
 		icon := g.props.GetString(RebaseIcon, "\uE728 ")
@@ -680,7 +691,7 @@ func (g *Git) setGitHEADContext() {
 				theirs = g.formatSHA(matches["theirs"])
 			default:
 				headIcon = branchIcon
-				theirs = g.formatHEAD(matches["theirs"])
+				theirs = g.formatBranch(matches["theirs"])
 			}
 			g.HEAD = fmt.Sprintf("%s%s%s into %s", icon, headIcon, theirs, formatDetached())
 			return
@@ -732,15 +743,6 @@ func (g *Git) setGitHEADContext() {
 	g.HEAD = formatDetached()
 }
 
-func (g *Git) formatHEAD(head string) string {
-	maxLength := g.props.GetInt(BranchMaxLength, 0)
-	if maxLength == 0 || len(head) < maxLength {
-		return head
-	}
-	symbol := g.props.GetString(TruncateSymbol, "")
-	return head[0:maxLength] + symbol
-}
-
 func (g *Git) formatSHA(sha string) string {
 	if len(sha) <= 7 {
 		return sha
@@ -765,7 +767,7 @@ func (g *Git) setPrettyHEADName() {
 		if strings.HasPrefix(HEADRef, BRANCHPREFIX) {
 			branchName := strings.TrimPrefix(HEADRef, BRANCHPREFIX)
 			g.Ref = branchName
-			g.HEAD = fmt.Sprintf("%s%s", g.props.GetString(BranchIcon, "\uE0A0"), g.formatHEAD(branchName))
+			g.HEAD = fmt.Sprintf("%s%s", g.props.GetString(BranchIcon, "\uE0A0"), g.formatBranch(branchName))
 			return
 		}
 		// no branch, points to commit
